@@ -3,7 +3,7 @@
  * Author: Brent Hendricks
  * Project: GGZ Text Client 
  * Date: 9/26/00
- * $Id: input.c 7930 2006-03-15 13:08:35Z josef $
+ * $Id: input.c 8535 2006-08-26 01:40:11Z jdorje $
  *
  * Functions for inputing commands from the user
  *
@@ -64,7 +64,7 @@ static void input_handle_beep(char* line);
 static void input_handle_launch(char *line);
 static void input_handle_exit(void);
 static void input_handle_log(char *line);
-static int input_roomnumber(const char *line);
+static void input_handle_admin(char* line);
 
 static char delim[] = " \n";
 static char command_prefix = '/';
@@ -132,6 +132,9 @@ void input_commandhandler(char *current)
 		|| (strcmp(command, "quit") == 0)) {
 			input_handle_exit();
 		}
+		else if (strcmp(command, "admin") == 0) {
+			input_handle_admin(current);
+		}
 		else if (strcmp(command, "version") == 0) {
 			output_text(_("--- Client version: %s"), VERSION);
 		}
@@ -317,25 +320,27 @@ static void input_handle_join(char* line)
 }
 
 
-static int input_roomnumber(const char *line)
+static GGZRoom *input_room(const char *line)
 {
 	GGZRoom *room;
 	int i;
 
-	if(!line) return -1;
+	if(!line) return NULL;
 	for(i = 0; i < ggzcore_server_get_num_rooms(server); i++)
 	{
 		room = ggzcore_server_get_nth_room(server, i);
-		if(!ggz_strcasecmp(ggzcore_room_get_name(room), line)) return i;
+		if (!ggz_strcasecmp(ggzcore_room_get_name(room), line)) {
+			return room;
+		}
 	}
 
-	return atoi(line);
+	return ggzcore_server_get_nth_room(server, atoi(line));
 }
 
 
 static void input_handle_join_room(char* line)
 {
-	int roomid;
+	GGZRoom *room;
 	GGZStateID state = ggzcore_server_get_state(server);
 	int ret;
 
@@ -346,10 +351,10 @@ static void input_handle_join_room(char* line)
 	}
 
 	if (line) {
-		roomid = input_roomnumber(line);
+		room = input_room(line);
 		server_progresswait();
 		server_workinprogress(COMMAND_JOIN, 1);
-		ret = ggzcore_server_join_room(server, roomid);
+		ret = ggzcore_server_join_room(server, room);
 		if(ret < 0) {
 			server_workinprogress(COMMAND_JOIN, 0);
 			output_text(_("Room %s does not exist."), line);
@@ -362,12 +367,12 @@ static void input_handle_join_room(char* line)
 
 static void input_handle_desc(char* line)
 {
-	int roomid;
+	GGZRoom *room;
 	const char* desc;
 
 	if (line) {
-		roomid = input_roomnumber(line);
-		desc = ggzcore_room_get_desc(ggzcore_server_get_nth_room(server, roomid));
+		room = input_room(line);
+		desc = ggzcore_room_get_desc(room);
 		output_text("%s", desc);
 	} else {
 		output_text(_("Describe which room?"));
@@ -418,14 +423,33 @@ static void input_handle_msg(char* line)
 	char *player;
 	char *msg;
 	GGZRoom *room = ggzcore_server_get_cur_room(server);
+	GGZStateID state = ggzcore_server_get_state(server);
 
 	if (!(player = strsep(&line, delim)))
+	{
+		output_text(_("Error: Missing player name."));
+		output_text(_("Syntax: /msg <player> <msg>"));
 		return;
-	
+	}
+
 	if (line && strcmp(line, "") != 0) {
-		msg = ggz_strdup(line);
-		server_progresswait();
-		ggzcore_room_chat(room, GGZ_CHAT_PERSONAL, player, msg);
+		if((int)state == -1 || state == GGZ_STATE_OFFLINE)
+		{
+			output_text(_("You must connect to a server first."));
+		}
+		else if(!room)
+		{
+			output_text(_("You must join a room first."));
+		}
+		else
+		{
+			msg = ggz_strdup(line);
+			server_progresswait();
+			ggzcore_room_chat(room, GGZ_CHAT_PERSONAL, player, msg);
+		}
+	} else {
+		output_text(_("Error: Missing message."));
+		output_text(_("Syntax: /msg <player> <msg>"));
 	}
 }
 
@@ -478,7 +502,7 @@ static GGZModule *input_get_module(void)
 			    "Maybe try 'list types'?"));
 		return NULL;
 	}
-	
+
 	name = ggzcore_gametype_get_name(type);
 	engine = ggzcore_gametype_get_prot_engine(type);
 	version = ggzcore_gametype_get_prot_version(type);
@@ -493,7 +517,7 @@ static GGZModule *input_get_module(void)
 		if ((getenv("DISPLAY")) && ((env == GGZ_ENVIRONMENT_XWINDOW) ||
 			(env == GGZ_ENVIRONMENT_XFULLSCREEN))) module = tmp;
 	}
-			
+
 	if (!module) {
 		output_text(_("No suitable game modules (out of %i) defined for that game."), num);
 		output_text(_("Download one from %s."),
@@ -580,3 +604,47 @@ static void input_handle_log(char *line)
 	output_log_init(line);
 }
 
+static void input_handle_admin(char* line)
+{
+	GGZRoom *room;
+	char *command, *player, *reason;
+	GGZStateID state = ggzcore_server_get_state(server);
+
+	if((int)state == -1 || state == GGZ_STATE_OFFLINE)
+	{
+		output_text(_("You must connect to a server first."));
+		return;
+	}
+
+	if (!(command = strsep(&line, delim)))
+		return;
+
+	if (!(player = strsep(&line, delim)))
+		return;
+
+	reason = NULL;
+	if (line && strcmp(line, "") != 0) {
+		reason = line;
+	}
+
+	room = ggzcore_server_get_cur_room(server);
+
+	/* Type of administrative command */
+	if (strcmp(command, "gag") == 0) {
+		ggzcore_room_admin(room, GGZ_ADMIN_GAG, player, NULL);
+	}
+	else if (strcmp(command, "ungag") == 0) {
+		ggzcore_room_admin(room, GGZ_ADMIN_UNGAG, player, NULL);
+	}
+	else if (strcmp(command, "kick") == 0) {
+		if (reason) {
+			ggzcore_room_admin(room, GGZ_ADMIN_KICK, player, reason);
+		}
+		else {
+			output_text(_("Kicking a player requires a reason."));
+		}
+	}
+	else
+		output_text(_("Unknown admin command."));
+}
+
